@@ -251,8 +251,9 @@ class MainConf(BaseConfig):
         self.tempfiles = []
 
     def __del__(self):
-        for file_name in self.tempfiles:
-            os.unlink(file_name)
+        if hasattr(self, 'tempfiles'):
+            for file_name in self.tempfiles:
+                os.unlink(file_name)
 
     @property
     def get_reposdir(self):
@@ -287,7 +288,7 @@ class MainConf(BaseConfig):
                 temp_fd, temp_path = tempfile.mkstemp(prefix='dnf-downloaded-config-')
                 self.tempfiles.append(temp_path)
                 try:
-                    downloader.downloadURL(None, val, temp_fd)
+                    downloader.downloadURL(self._config, val, temp_fd)
                 except RuntimeError as e:
                     raise dnf.exceptions.ConfigError(
                         _('Configuration file URL "{}" could not be downloaded:\n'
@@ -424,53 +425,11 @@ class MainConf(BaseConfig):
     @releasever.setter
     def releasever(self, val):
         # :api
-        """
-        Sets the releasever variable and sets releasever_major and
-        releasever_minor accordingly. releasever_major is set to the part of
-        $releasever before the first ".". releasever_minor is set to the part
-        after the first ".".
-        """
         if val is None:
             self.substitutions.pop('releasever', None)
             return
         self.substitutions['releasever'] = str(val)
 
-    @property
-    def releasever_major(self):
-        # :api
-        return self.substitutions.get('releasever_major')
-
-    @releasever_major.setter
-    def releasever_major(self, val):
-        # :api
-        """
-        Override the releasever_major variable, which is usually derived from
-        the releasever variable. This setter does not update the value of
-        $releasever.
-        """
-        if val is None:
-            self.substitutions.pop('releasever_major', None)
-            return
-        self.substitutions['releasever_major'] = str(val)
-
-    @property
-    def releasever_minor(self):
-        # :api
-        return self.substitutions.get('releasever_minor')
-
-    @releasever_minor.setter
-    def releasever_minor(self, val):
-        # :api
-        """
-        Override the releasever_minor variable, which is usually derived from
-        the releasever variable. This setter does not update the value of
-        $releasever.
-        """
-        if val is None:
-            self.substitutions.pop('releasever_minor', None)
-            return
-        self.substitutions['releasever_minor'] = str(val)
-
     @property
     def arch(self):
         # :api
